GetInterface class abstract
GetInterface allows any auxiliary package to be merged into the "Get" class through extensions
Constructors
Properties
- arguments → dynamic
-
Available on GetInterface, provided by the GetNavigationExt extension
give current argumentsno setter - bottomBarHeight → double
-
Available on GetInterface, provided by the GetNavigationExt extension
The distance from the bottom edge to the first unpadded pixel, in physical pixels.no setter - context → BuildContext?
-
Available on GetInterface, provided by the GetNavigationExt extension
give access to currentContextno setter - currentRoute → String
-
Available on GetInterface, provided by the GetNavigationExt extension
give name from current routeno setter - defaultDialogTransitionCurve → Curve
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - defaultDialogTransitionDuration → Duration
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - defaultOpaqueRoute → bool
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - defaultPopGesture → bool?
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - defaultTransition → Transition?
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - defaultTransitionCurve → Curve
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - defaultTransitionDuration → Duration
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - deviceLocale → Locale?
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - engine → WidgetsBinding
-
Available on GetInterface, provided by the GetNavigationExt extension
The current null safe WidgetsBindingno setter - fallbackLocale ↔ Locale?
-
Available on GetInterface, provided by the LocalesIntl extension
getter/setter pair - focusScope → FocusNode?
-
Available on GetInterface, provided by the GetNavigationExt extension
give access to FocusScope.of(context)no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
Available on GetInterface, provided by the GetNavigationExt extension
The vertical extent of this sizeno setter - iconColor → Color?
-
Available on GetInterface, provided by the GetNavigationExt extension
give access to Theme.of(context).iconTheme.colorno setter - isBottomSheetOpen → bool?
-
Available on GetInterface, provided by the GetNavigationExt extension
check if bottomsheet is openno setter - isDarkMode → bool
-
Available on GetInterface, provided by the GetNavigationExt extension
Check if dark mode theme is enableno setter - isDialogOpen → bool?
-
Available on GetInterface, provided by the GetNavigationExt extension
check if dialog is openno setter - isLogEnable ↔ bool
-
getter/setter pair
- isOpaqueRouteDefault → bool
-
Available on GetInterface, provided by the GetNavigationExt extension
check if default opaque route is enableno setter - isOverlaysClosed → bool
-
Available on GetInterface, provided by the GetNavigationExt extension
Returns true if there is no Snackbar, Dialog or BottomSheet openno setter - isOverlaysOpen → bool
-
Available on GetInterface, provided by the GetNavigationExt extension
Returns true if a Snackbar, Dialog or BottomSheet is currently OPENno setter - isPlatformDarkMode → bool
-
Available on GetInterface, provided by the GetNavigationExt extension
Check if dark mode theme is enable on platform on android Q+no setter - isSnackbarOpen → bool
-
Available on GetInterface, provided by the GetNavigationExt extension
check if snackbar is openno setter -
key
→ GlobalKey<
NavigatorState> -
Available on GetInterface, provided by the GetNavigationExt extension
no setter -
keys
→ Map<
String, GetDelegate> -
Available on GetInterface, provided by the GetNavigationExt extension
no setter - locale ↔ Locale?
-
Available on GetInterface, provided by the LocalesIntl extension
getter/setter pair - log ↔ LogWriterCallback
-
getter/setter pair
- mediaQuery → MediaQueryData
-
Available on GetInterface, provided by the GetNavigationExt extension
give access to Mediaquery.of(context)no setter - overlayContext → BuildContext?
-
Available on GetInterface, provided by the GetNavigationExt extension
give access to current Overlay Contextno setter -
parameters
→ Map<
String, String?> -
Available on GetInterface, provided by the GetNavigationExt extension
no setter - pixelRatio → double
-
Available on GetInterface, provided by the GetNavigationExt extension
The number of device pixels for each logical pixel.no setter - previousRoute → String
-
Available on GetInterface, provided by the GetNavigationExt extension
give name from previous routeno setter - rawRoute → Route?
-
Available on GetInterface, provided by the GetNavigationExt extension
check a raw current routeno setter - rootController → GetRootState
-
Available on GetInterface, provided by the GetNavigationExt extension
GetRoot 控制器no setter - routing → Routing
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → Size
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - smartManagement ↔ SmartManagement
-
getter/setter pair
- statusBarHeight → double
-
Available on GetInterface, provided by the GetNavigationExt extension
The distance from the top edge to the first unpadded pixel, in physical pixels.no setter - testMode ↔ bool
-
Available on GetInterface, provided by the GetNavigationExt extension
getter/setter pair - textScaleFactor → double
-
Available on GetInterface, provided by the GetNavigationExt extension
The system-reported text scale.no setter - textTheme → TextTheme
-
Available on GetInterface, provided by the GetNavigationExt extension
give access to TextTheme.of(context)no setter - theme → ThemeData
-
Available on GetInterface, provided by the GetNavigationExt extension
give access to Theme.of(context)no setter -
translations
→ Map<
String, Map< String, String> > -
Available on GetInterface, provided by the LocalesIntl extension
no setter - width → double
-
Available on GetInterface, provided by the GetNavigationExt extension
The horizontal extent of this size.no setter - window → PlatformDispatcher
-
Available on GetInterface, provided by the GetNavigationExt extension
The window to which this binding is bound.no setter
Methods
-
addKey(
GlobalKey< NavigatorState> newKey) → GlobalKey<NavigatorState> ? -
Available on GetInterface, provided by the GetNavigationExt extension
-
addTranslations(
Map< String, Map< tr) → voidString, String> > -
Available on GetInterface, provided by the LocalesIntl extension
-
appendTranslations(
Map< String, Map< tr) → voidString, String> > -
Available on GetInterface, provided by the LocalesIntl extension
-
appUpdate(
) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
args<
T> () → T -
Available on GetInterface, provided by the GetNavigationExt extension
-
asap<
T> (T computation(), {bool condition()?}) → FutureOr< T> -
Available on GetInterface, provided by the LoopEventsExt extension
允许你尽可能快地执行一个computation计算或操作, 但同时提供了通过condition条件延迟执行的选项. 例如假设你有一个需要执行的计算密集型任务,但你希望避免在用户交互高峰时(例如滚动列表时)执行,以免影响应用的流畅度。 你可以设置 condition 来检查当前是否有用户交互,如果有,则延迟执行;否则,立即执行。 -
back<
T> ({T? result, bool canPop = true, int times = 1, String? id}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.popUntil() shortcut.
-
backLegacy<
T> ({T? result, bool closeOverlays = false, bool canPop = true, int times = 1, String? id}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Pop the current page, snackbar, dialog or bottomsheet in the stack -
bottomSheet<
T> (Widget bottomsheet, {Color? backgroundColor, double? elevation, bool persistent = true, ShapeBorder? shape, Clip? clipBehavior, Color? barrierColor, bool? ignoreSafeArea, bool isScrollControlled = false, bool isDismissible = true, bool enableDrag = true, RouteSettings? settings, Duration? enterBottomSheetDuration, Duration? exitBottomSheetDuration, Curve? curve}) → Future< T?> -
Available on GetInterface, provided by the ExtensionBottomSheet extension
-
call<
T> () → T -
Available on GetInterface, provided by the Inst extension
-
changeTheme(
ThemeData theme) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
changeThemeMode(
ThemeMode themeMode) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
clearTranslations(
) → void -
Available on GetInterface, provided by the LocalesIntl extension
-
close<
T extends Object> ({bool closeAll = true, bool closeSnackbar = true, bool closeDialog = true, bool closeBottomSheet = true, String? id, T? result}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.popUntil() (with predicate) shortcut .
-
closeAllBottomSheets(
{String? id}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
closeAllDialogs(
{String? id}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
closeAllDialogsAndBottomSheets(
String? id) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
closeAllOverlays(
) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
closeAllSnackbars(
) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
closeBottomSheet<
T> ({String? id, T? result}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
closeCurrentSnackbar(
) → Future< void> -
Available on GetInterface, provided by the GetNavigationExt extension
-
closeDialog<
T> ({String? id, T? result}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Close the currently open dialog, returning aresult, if provided -
closeOverlay<
T> ({String? id, T? result}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Close the current overlay returning theresult, if provided -
defaultDialog<
T> ({String title = "Alert", EdgeInsetsGeometry? titlePadding, TextStyle? titleStyle, Widget? content, String? id, EdgeInsetsGeometry? contentPadding, VoidCallback? onConfirm, VoidCallback? onCancel, VoidCallback? onCustom, Color? cancelTextColor, Color? confirmTextColor, String? textConfirm, String? textCancel, String? textCustom, Widget? confirm, Widget? cancel, Widget? custom, Color? backgroundColor, bool barrierDismissible = true, Color? buttonColor, String middleText = "\n", TextStyle? middleTextStyle, double radius = 20.0, List< Widget> ? actions, PopInvokedWithResultCallback<T> ? onWillPop, }) → Future<T?> -
Available on GetInterface, provided by the ExtensionDialog extension
Custom UI Dialog. -
delegate<
TDelegate extends RouterDelegate< (TPage> , TPage>) → TDelegate? -
Available on GetInterface, provided by the GetNavigationExt extension
Casts the stored router delegate to a desired type -
delete<
S> ({String? tag, String? key, bool force = false}) → bool -
Available on GetInterface, provided by the Inst extension
Delete registered Class InstanceS(ortag) and, closes any open controllersDisposableInterface, cleans up the memory -
deleteAll(
{bool force = false}) → void -
Available on GetInterface, provided by the Inst extension
Delete all registered Class Instances and, closes any open controllersDisposableInterface, cleans up the memory -
dialog<
T> (Widget widget, {bool barrierDismissible = true, Color? barrierColor, bool useSafeArea = true, Object? arguments, Duration? transitionDuration, Curve? transitionCurve, String? name, RouteSettings? routeSettings, String? id}) → Future< T?> -
Available on GetInterface, provided by the ExtensionDialog extension
Show a dialog. You can pass atransitionDurationand/ortransitionCurve, overriding the defaults when the dialog shows up and closes. When the dialog closes, uses those animations in reverse. -
find<
S> ({String? tag}) → S -
Available on GetInterface, provided by the Inst extension
Finds the registered type <S> (ortag) In case of using Get.createto register a type <S> ortag, it will create an instance each time you call find. If the registered type <S> (ortag) is a Controller, it will initialize it's lifecycle. 查找已注册的类型 <S> (或tag) 如果使用 Get.create注册类型 <S> 或tag, 每次调用 find 时,它都会创建一个实例. 如果已注册的类型 <S> (或tag) 是控制器,它将初始化其生命周期。 -
findOrNull<
S> ({String? tag}) → S? -
Available on GetInterface, provided by the Inst extension
The findOrNull method will return the instance if it is registered; otherwise, it will return null. 如果已注册,则 findOrNull 方法将返回该实例; 否则,它将返回 null. -
forceAppUpdate(
) → Future< void> -
Available on GetInterface, provided by the GetNavigationExt extension
As a rule, Flutter knows which widget to update, so this command is rarely needed. We can mention situations where you use const so that widgets are not updated with setState, but you want it to be forcefully updated when an event like language change happens. using context to make the widget dirty for performRebuild() is a viable solution. However, in situations where this is not possible, or at least, is not desired by the developer, the only solution for updating widgets that Flutter does not want to update is to use reassemble to forcibly rebuild all widgets. Attention: calling this function will reconstruct the application from the sketch, use this with caution. Your entire application will be rebuilt, and touch events will not work until the end of rendering. 通常情况下,Flutter 能够智能的知道要更新哪个部件,因此很少需要这条命令。 它通过对 Widget 树的有效管理和 setState 方法的调用来实现这一点。 因此,在绝大多数情况下,开发者不需要手动介入 Widget 的更新过程。 如果在 Widget 构建过程中使用了 const 关键字,该 Widget 及其子树将不会在 setState 调用时更新。 这是因为 const 创建的是编译时常量,Flutter 认为它们在整个应用生命周期内不会改变。 在一些特殊场景下,尽管 Widget 被定义为 const,但仍然需要强制更新。 一个典型的例子是应用语言更改时。 虽然可以通过使 Widget 变"脏" (dirty) 来强制重建 (performRebuild),但在某些情况下,这可能不是可行的或者开发者不希望这样做。 在 Flutter 不愿意更新 Widget,而开发者又确实需要更新时,可以使用 reassemble 方法强制整个应用的 Widget 树进行重建。 这相当于从头开始重构应用的 UI。 ! 注意,调用 reassemble 会导致整个应用重新构建,这是一个非常重的操作。 ! 在渲染完成之前,触摸事件等可能无法正常工作。因此,除非确有必要,否则应避免使用此方法。 -
generalDialog<
T> ({required RoutePageBuilder pageBuilder, bool barrierDismissible = false, String? barrierLabel, Color barrierColor = const Color(0x80000000), Duration transitionDuration = const Duration(milliseconds: 200), RouteTransitionsBuilder? transitionBuilder, RouteSettings? routeSettings, String? id}) → Future< T?> -
Available on GetInterface, provided by the ExtensionDialog extension
Api from showGeneralDialog with no context -
getInstanceInfo<
S> ({String? tag}) → InstanceInfo -
Available on GetInterface, provided by the Inst extension
-
isPrepared<
S> ({String? tag}) → bool -
Available on GetInterface, provided by the Inst extension
Checks if a lazy factory callbackGet.lazyPut()that returns an Instance<S> is registered in memory. -
isRegistered<
S> ({String? tag}) → bool -
Available on GetInterface, provided by the Inst extension
Check if a Class Instance<S> (ortag) is registered in memory. -
lazyPut<
S> (InstanceBuilderCallback< S> builder, {String? tag, bool? fenix, bool permanent = false}) → void -
Available on GetInterface, provided by the Inst extension
Creates a new Instancelazily from the<S>builder()callback. -
lazyReplace<
P> (InstanceBuilderCallback< P> builder, {String? tag, bool? fenix}) → void -
Available on GetInterface, provided by the Inst extension
Replaces a parent instance with a new Instance -
markAsDirty<
S> ({String? tag, String? key}) → void -
Available on GetInterface, provided by the Inst extension
-
nestedKey(
String? key) → GetDelegate? -
Available on GetInterface, provided by the GetNavigationExt extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
off<
T> (Widget page(), {bool? opaque, Transition? transition, Curve? curve, bool? popGesture, String? id, String? routeName, dynamic arguments, List< BindingsInterface> bindings = const [], bool fullscreenDialog = false, bool preventDuplicates = true, Duration? duration, double gestureWidth(BuildContext context)?}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.pushReplacement() shortcut .
-
offAll<
T> (Widget page(), {bool predicate(GetPage)?, bool? opaque, bool? popGesture, String? id, String? routeName, dynamic arguments, List< BindingsInterface> bindings = const [], bool fullscreenDialog = false, Transition? transition, Curve? curve, Duration? duration, double gestureWidth(BuildContext context)?}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Push apageand pop several pages in the stack untilpredicatereturns true.predicateis optional -
offAllNamed<
T> (String newRouteName, {dynamic arguments, String? id, Map< String, String> ? parameters}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.pushNamedAndRemoveUntil() shortcut.
-
offAndToNamed<
T> (String page, {dynamic arguments, String? id, dynamic result, Map< String, String> ? parameters}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.popAndPushNamed() shortcut.
-
offNamed<
T> (String page, {dynamic arguments, String? id, Map< String, String> ? parameters}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.pushReplacementNamed() shortcut.
-
offNamedUntil<
T> (String page, bool predicate(GetPage)?, {String? id, dynamic arguments, Map< String, String> ? parameters}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.pushNamedAndRemoveUntil() shortcut.
-
offUntil<
T> (Widget page(), bool predicate(GetPage), [Object? arguments, String? id]) → Future< T?> -
Available on GetInterface, provided by the GetNavigationExt extension
-
put<
S> (S dependency, {String? tag, bool permanent = false}) → S -
Available on GetInterface, provided by the Inst extension
Holds a reference to every registered callback when usingGet.lazyPut() -
putOrFind<
S> (InstanceBuilderCallback< S> dep, {String? tag}) → S -
Available on GetInterface, provided by the Inst extension
-
rawSnackbar(
{String? title, String? message, Widget? titleText, Widget? messageText, Widget? icon, bool instantInit = true, bool shouldIconPulse = true, double? maxWidth, EdgeInsets margin = const EdgeInsets.all(0.0), EdgeInsets padding = const EdgeInsets.all(16), double borderRadius = 0.0, Color? borderColor, double borderWidth = 1.0, Color backgroundColor = const Color(0xFF303030), Color? leftBarIndicatorColor, List< BoxShadow> ? boxShadows, Gradient? backgroundGradient, Widget? mainButton, OnTap? onTap, Duration? duration = const Duration(seconds: 3), bool isDismissible = true, DismissDirection? dismissDirection, bool showProgressIndicator = false, AnimationController? progressIndicatorController, Color? progressIndicatorBackgroundColor, Animation<Color> ? progressIndicatorValueColor, SnackPosition snackPosition = SnackPosition.bottom, SnackStyle snackStyle = SnackStyle.floating, Curve forwardAnimationCurve = Curves.easeOutCirc, Curve reverseAnimationCurve = Curves.easeOutCirc, Duration animationDuration = const Duration(seconds: 1), SnackbarStatusCallback? snackbarStatus, double barBlur = 0.0, double overlayBlur = 0.0, Color? overlayColor, Form? userInputForm}) → SnackbarController -
Available on GetInterface, provided by the ExtensionSnackbar extension
-
reload<
S> ({String? tag, String? key, bool force = false}) → void -
Available on GetInterface, provided by the Inst extension
-
reloadAll(
{bool force = false}) → void -
Available on GetInterface, provided by the Inst extension
-
removeRoute(
String name, {String? id}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.removeRoute() shortcut.
-
replace<
P> (P child, {String? tag}) → void -
Available on GetInterface, provided by the Inst extension
Replace a parent instance of a class in dependency management with achildinstance -
reset(
{bool clearRouteBindings = true}) → void -
Available on GetInterface, provided by the GetResetExt extension
-
resetInstance(
{bool clearRouteBindings = true}) → bool -
Available on GetInterface, provided by the ResetInstance extension
Clears all registered instances (and/or tags). Even the persistent ones. This should be used at the end or tearDown of unit tests. -
searchDelegate(
String? k) → GetDelegate -
Available on GetInterface, provided by the GetNavigationExt extension
根据 key 获取 GetDelegate -
showOverlay<
T> ({required Future< T> asyncFunction(), Color opacityColor = Colors.black, Widget? loadingWidget, double opacity = .5}) → Future<T> -
Available on GetInterface, provided by the OverlayExt extension
-
showSnackbar(
GetSnackBar snackbar) → SnackbarController -
Available on GetInterface, provided by the ExtensionSnackbar extension
-
snackbar(
String title, String message, {Color? colorText, Duration? duration = const Duration(seconds: 3), bool instantInit = true, SnackPosition? snackPosition, Widget? titleText, Widget? messageText, Widget? icon, bool? shouldIconPulse, double? maxWidth, EdgeInsets? margin, EdgeInsets? padding, double? borderRadius, Color? borderColor, double? borderWidth, Color? backgroundColor, Color? leftBarIndicatorColor, List< BoxShadow> ? boxShadows, Gradient? backgroundGradient, TextButton? mainButton, OnTap? onTap, OnHover? onHover, bool? isDismissible, bool? showProgressIndicator, DismissDirection? dismissDirection, AnimationController? progressIndicatorController, Color? progressIndicatorBackgroundColor, Animation<Color> ? progressIndicatorValueColor, SnackStyle? snackStyle, Curve? forwardAnimationCurve, Curve? reverseAnimationCurve, Duration? animationDuration, double? barBlur, double? overlayBlur, SnackbarStatusCallback? snackbarStatus, Color? overlayColor, Form? userInputForm}) → SnackbarController -
Available on GetInterface, provided by the ExtensionSnackbar extension
-
spawn<
S> (InstanceBuilderCallback< S> builder, {String? tag, bool permanent = true}) → void -
Available on GetInterface, provided by the Inst extension
Creates a new Class InstanceSfrom the builder callbackS. Every time find<S>() is used, it calls the builder method to generate a new InstanceS. It also registers eachinstance.onClose()with the current RouteGet.referenceto keep the lifecycle active. Is important to know that the instances created are only stored per Route. So, if you callGet.delete<T>()the "instance factory" used in this method (Get.spawn<T>()) will be removed, but NOT the instances already created by it. -
to<
T extends Object?> (Widget page(), {bool? opaque, Transition? transition, Curve? curve, Duration? duration, String? id, String? routeName, bool fullscreenDialog = false, dynamic arguments, List< BindingsInterface> bindings = const [], bool preventDuplicates = true, bool? popGesture, bool showCupertinoParallax = true, double gestureWidth(BuildContext context)?, bool rebuildStack = true, PreventDuplicateHandlingMode preventDuplicateHandlingMode = PreventDuplicateHandlingMode.reorderRoutes}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.push() shortcut.
-
toEnd<
T> (FutureOr< T> computation()) → Future<T> -
Available on GetInterface, provided by the LoopEventsExt extension
-
toNamed<
T> (String page, {dynamic arguments, dynamic id, bool preventDuplicates = true, Map< String, String> ? parameters}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.pushNamed() shortcut.
-
toString(
) → String -
A string representation of this object.
inherited
-
until(
bool predicate(GetPage), {String? id}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.popUntil() shortcut.
-
updateLocale(
Locale l) → Future< void> -
Available on GetInterface, provided by the GetNavigationExt extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited