get_navigation/get_navigation library
Classes
- BackButtonCallback
- CircularRevealClipper
- CircularRevealTransition
- CustomTransition
- Dependencies
- FadeInTransition
-
GetBackGestureController<
T> -
GetBackGestureDetector<
T> -
GetBackGestureDetectorState<
T> - GetCupertinoApp
- GetDelegate
- 导航代理, 用来处理导航相关的逻辑
- GetInformationParser
- GetMaterialApp
- GetMiddleware
- The Page Middlewares. The Functions will be called in this order (( redirect -> onPageCalled -> onBindingsStart -> onPageBuildStart -> onPageBuilt -> onPageDispose ))
-
GetModalBottomSheetRoute<
T> - GetObserver
-
GetPage<
T> -
GetPageRoute<
T> - GetRouterOutlet
- GetSnackBar
- GetSnackBarState
-
IndexedRouteBuilder<
T> - 这个类接受一个路由列表和一个构建方法,基于当前路由返回对应的 Widget。
- LeftToRightFadeTransition
- MiddlewareRunner
- Module
- ModuleState
- NoTransition
- PageRedirect
- PageSettings
- 存储了 GetPage 的一些信息
- ParseRouteTree
- PathDecoded
- 包含用于匹配路径的正则表达式 regex 和提取的路径参数名称列表 keys 的对象。
- RightToLeftFadeTransition
- RouteDecoder
- RouteListenerState
- RouteReport
- RouteReportState
- RouterListener
- RouterListenerInherited
- RouterListenerState
-
RouterOutlet<
TDelegate extends RouterDelegate< T> , T extends Object> -
RouterOutletState<
TDelegate extends RouterDelegate< T> , T extends Object> - Routing
- SizeTransitions
- SlideDownTransition
- SlideLeftTransition
- SlideRightTransition
- SlideTopTransition
- SnackbarController
- SnackBarQueue
- Translations
- ZoomInTransition
Enums
- PopMode
- Enables the user to customize the intended pop behavior
- PreventDuplicateHandlingMode
- Enables the user to customize the behavior when pushing multiple routes that shouldn't be duplicates
- RowStyle
- SnackbarStatus
-
Indicates Status of snackbar
SnackbarStatus.OPENSnack is fully open,SnackbarStatus.CLOSEDSnackbar has closed,SnackbarStatus.OPENINGStarts with the opening animation and ends with the full snackbar display,SnackbarStatus.CLOSINGStarts with the closing animation and ends with the full snackbar dispose - SnackHoverState
- Indicates if the mouse entered or exited
- SnackPosition
-
Indicates if snack is going to start at the
TOPor at theBOTTOM - SnackStyle
- Indicates if snack will be attached to the edge of the screen or not
- Transition
Mixins
-
GetPageRouteTransitionMixin<
T> -
PageRouteReportMixin<
T> -
RouteReportMixin<
T extends StatefulWidget> -
RouterListenerMixin<
T extends StatefulWidget>
Extensions
Constants
-
rtlLanguages
→ const List<
String>
Properties
-
It replaces the Flutter Navigator, but needs no context.
You can to use navigator.push(YourRoute()) rather
Navigator.push(context, YourRoute());
no setter
Functions
-
removeLastHistory(
String? url) → void -
setUrlStrategy(
) → void
Typedefs
- GetPageBuilder = Widget Function()
-
GetRouteAwarePageBuilder<
T> = Widget Function([GetPageRoute< T> ? route]) - OnHover = void Function(GetSnackBar snack, SnackHoverState snackHoverState)
- OnTap = void Function(GetSnackBar snack)
- SnackbarStatusCallback = void Function(SnackbarStatus? status)