RouterReportManager<T> class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

appendRouteByCreate(GetLifeCycleMixin i) → void
clearRouteKeys() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printInstanceStack() → void
reportCurrentRoute(T newRoute) → void
保存当前路由
reportDependencyLinkedToRoute(String dependencyKey) → void
Links a Class instance S (or tag) to the current route. Requires usage of GetMaterialApp. 将类实例 S(或 tag)绑定到当前路由. 需要使用 GetMaterialApp.
reportRouteDispose(T disposed) → void
reportRouteWillDispose(T disposed) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance RouterReportManager
no setter

Static Methods

dispose() → void