PreventDuplicateHandlingMode enum

Enables the user to customize the behavior when pushing multiple routes that shouldn't be duplicates

Inheritance
Available extensions

Values

popUntilOriginalRoute → const PreventDuplicateHandlingMode

Removes the _activePages entries until it reaches the old route 移除 _activePages 中找到的重复路由后面的所有路由

doNothing → const PreventDuplicateHandlingMode

Simply don't push the new route 不做任何操作

reorderRoutes → const PreventDuplicateHandlingMode

Recommended - Moves the old route entry to the front

With this mode, you guarantee there will be only one route entry for each location 推荐 - 将旧路由从原本位置移除并移到最前面 使用此模式,可以保证路由栈中只存在唯一的路由

recreate → const PreventDuplicateHandlingMode

和 reorderRoutes 一样

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PreventDuplicateHandlingMode>
A constant List of the values in this enum, in order of their declaration.