PathDecoded class

包含用于匹配路径的正则表达式 regex 和提取的路径参数名称列表 keys 的对象。

Annotations

Constructors

PathDecoded(RegExp regex, List<String?> keys)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
keys List<String?>
提取的路径参数名称列表
final
regex RegExp
用于匹配路径的正则表达式
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override