ParseRouteTree class

Constructors

ParseRouteTree({required List<GetPage> routes})

Properties

hashCode int
The hash code for this object.
no setterinherited
routes List<GetPage>
路由列表, 即 app_pages.dart 中的 routes
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRoute<T>(GetPage<T> route) → void
addRoutes<T>(List<GetPage<T>> getPages) → void
matchRoute(String name, {PageSettings? arguments}) RouteDecoder
从整个路由数中筛选出匹配的路由子树 返回一个 RouteDecoder 对象, 其中包含所有匹配的路由子树和参数信息。
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeRoute<T>(GetPage<T> route) → void
removeRoutes<T>(List<GetPage<T>> getPages) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited