route_manager library

Get Navigator allows you to navigate routes, open snackbars, dialogs and bottomsheets easily, and without the need for context.

Classes

BackButtonCallback
CircularRevealClipper
CircularRevealTransition
CustomTransition
Dependencies
Engine
FadeInTransition
GetBackGestureController<T>
GetBackGestureDetector<T>
GetBackGestureDetectorState<T>
GetCupertinoApp
GetDelegate
导航代理, 用来处理导航相关的逻辑
GetInformationParser
GetInterface
GetInterface allows any auxiliary package to be merged into the "Get" class through extensions
GetMaterialApp
GetMiddleware
The Page Middlewares. The Functions will be called in this order (( redirect -> onPageCalled -> onBindingsStart -> onPageBuildStart -> onPageBuilt -> onPageDispose ))
GetModalBottomSheetRoute<T>
GetNavigator
GetObserver
GetPage<T>
GetPageRoute<T>
GetRouterOutlet
GetSnackBar
GetSnackBarState
IndexedRouteBuilder<T>
这个类接受一个路由列表和一个构建方法,基于当前路由返回对应的 Widget
InheritedNavigator
LeftToRightFadeTransition
MiddlewareRunner
Module
ModuleState
NoTransition
PageRedirect
PageSettings
存储了 GetPage 的一些信息
ParseRouteTree
PathDecoded
包含用于匹配路径的正则表达式 regex 和提取的路径参数名称列表 keys 的对象。
RightToLeftFadeTransition
RouteDecoder
RouteListenerState
RouteReport
RouteReportState
RouterListener
RouterListenerInherited
RouterListenerState
RouterOutlet<TDelegate extends RouterDelegate<T>, T extends Object>
RouterOutletState<TDelegate extends RouterDelegate<T>, T extends Object>
Routing
SizeTransitions
SlideDownTransition
SlideLeftTransition
SlideRightTransition
SlideTopTransition
SnackbarController
SnackBarQueue
Translations
ZoomInTransition

Enums

PopMode
Enables the user to customize the intended pop behavior
PreventDuplicateHandlingMode
Enables the user to customize the behavior when pushing multiple routes that shouldn't be duplicates
RowStyle
SmartManagement
GetX by default disposes unused controllers from memory, Through different behaviors. SmartManagement.full SmartManagement.full is the default one. Dispose classes that are not being used and were not set to be permanent. In the majority of the cases you will want to keep this config untouched. If you new to GetX then don't change this. SmartManagement.onlyBuilder only controllers started in init: or loaded into a Binding with Get.lazyPut() will be disposed. If you use Get.put() or Get.putAsync() or any other approach, SmartManagement will not have permissions to exclude this dependency. With the default behavior, even widgets instantiated with "Get.put" will be removed, unlike SmartManagement.onlyBuilders. SmartManagement.keepFactoryJust like SmartManagement.full, it will remove it's dependencies when it's not being used anymore. However, it will keep their factory, which means it will recreate the dependency if you need that instance again.
SnackbarStatus
Indicates Status of snackbar SnackbarStatus.OPEN Snack is fully open, SnackbarStatus.CLOSED Snackbar has closed, SnackbarStatus.OPENING Starts with the opening animation and ends with the full snackbar display, SnackbarStatus.CLOSING Starts with the closing animation and ends with the full snackbar dispose
SnackHoverState
Indicates if the mouse entered or exited
SnackPosition
Indicates if snack is going to start at the TOP or at the BOTTOM
SnackStyle
Indicates if snack will be attached to the edge of the screen or not
Transition

Constants

rtlLanguages → const List<String>

Properties

Get → _GetImpl
final
It replaces the Flutter Navigator, but needs no context. You can to use navigator.push(YourRoute()) rather Navigator.push(context, YourRoute());
no setter

Functions

defaultLogWriterCallback(String value, {bool isError = false}) → void
default logger from GetX
removeLastHistory(String? url) → void
setUrlStrategy() → void

Typedefs

GetPageBuilder = Widget Function()
GetRouteAwarePageBuilder<T> = Widget Function([GetPageRoute<T>? route])
LogWriterCallback = void Function(String text, {bool isError})
VoidCallback from logs
OnHover = void Function(GetSnackBar snack, SnackHoverState snackHoverState)
OnTap = void Function(GetSnackBar snack)
SnackbarStatusCallback = void Function(SnackbarStatus? status)
ValueUpdater<T> = T Function()