GetNavigationExt extension
- on
Properties
- arguments → dynamic
-
Available on GetInterface, provided by the GetNavigationExt extension
give current argumentsno setter - bottomBarHeight → double
-
Available on GetInterface, provided by the GetNavigationExt extension
The distance from the bottom edge to the first unpadded pixel, in physical pixels.no setter - context → BuildContext?
-
Available on GetInterface, provided by the GetNavigationExt extension
give access to currentContextno setter - currentRoute → String
-
Available on GetInterface, provided by the GetNavigationExt extension
give name from current routeno setter - defaultDialogTransitionCurve → Curve
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - defaultDialogTransitionDuration → Duration
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - defaultOpaqueRoute → bool
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - defaultPopGesture → bool?
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - defaultTransition → Transition?
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - defaultTransitionCurve → Curve
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - defaultTransitionDuration → Duration
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - deviceLocale → Locale?
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - engine → WidgetsBinding
-
Available on GetInterface, provided by the GetNavigationExt extension
The current null safe WidgetsBindingno setter - focusScope → FocusNode?
-
Available on GetInterface, provided by the GetNavigationExt extension
give access to FocusScope.of(context)no setter - height → double
-
Available on GetInterface, provided by the GetNavigationExt extension
The vertical extent of this sizeno setter - iconColor → Color?
-
Available on GetInterface, provided by the GetNavigationExt extension
give access to Theme.of(context).iconTheme.colorno setter - isBottomSheetOpen → bool?
-
Available on GetInterface, provided by the GetNavigationExt extension
check if bottomsheet is openno setter - isDarkMode → bool
-
Available on GetInterface, provided by the GetNavigationExt extension
Check if dark mode theme is enableno setter - isDialogOpen → bool?
-
Available on GetInterface, provided by the GetNavigationExt extension
check if dialog is openno setter - isOpaqueRouteDefault → bool
-
Available on GetInterface, provided by the GetNavigationExt extension
check if default opaque route is enableno setter - isOverlaysClosed → bool
-
Available on GetInterface, provided by the GetNavigationExt extension
Returns true if there is no Snackbar, Dialog or BottomSheet openno setter - isOverlaysOpen → bool
-
Available on GetInterface, provided by the GetNavigationExt extension
Returns true if a Snackbar, Dialog or BottomSheet is currently OPENno setter - isPlatformDarkMode → bool
-
Available on GetInterface, provided by the GetNavigationExt extension
Check if dark mode theme is enable on platform on android Q+no setter - isSnackbarOpen → bool
-
Available on GetInterface, provided by the GetNavigationExt extension
check if snackbar is openno setter -
key
→ GlobalKey<
NavigatorState> -
Available on GetInterface, provided by the GetNavigationExt extension
no setter -
keys
→ Map<
String, GetDelegate> -
Available on GetInterface, provided by the GetNavigationExt extension
no setter - mediaQuery → MediaQueryData
-
Available on GetInterface, provided by the GetNavigationExt extension
give access to Mediaquery.of(context)no setter - overlayContext → BuildContext?
-
Available on GetInterface, provided by the GetNavigationExt extension
give access to current Overlay Contextno setter -
parameters
→ Map<
String, String?> -
Available on GetInterface, provided by the GetNavigationExt extension
no setter - pixelRatio → double
-
Available on GetInterface, provided by the GetNavigationExt extension
The number of device pixels for each logical pixel.no setter - previousRoute → String
-
Available on GetInterface, provided by the GetNavigationExt extension
give name from previous routeno setter - rawRoute → Route?
-
Available on GetInterface, provided by the GetNavigationExt extension
check a raw current routeno setter - rootController → GetRootState
-
Available on GetInterface, provided by the GetNavigationExt extension
GetRoot 控制器no setter - routing → Routing
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - size → Size
-
Available on GetInterface, provided by the GetNavigationExt extension
no setter - statusBarHeight → double
-
Available on GetInterface, provided by the GetNavigationExt extension
The distance from the top edge to the first unpadded pixel, in physical pixels.no setter - testMode ↔ bool
-
Available on GetInterface, provided by the GetNavigationExt extension
getter/setter pair - textScaleFactor → double
-
Available on GetInterface, provided by the GetNavigationExt extension
The system-reported text scale.no setter - textTheme → TextTheme
-
Available on GetInterface, provided by the GetNavigationExt extension
give access to TextTheme.of(context)no setter - theme → ThemeData
-
Available on GetInterface, provided by the GetNavigationExt extension
give access to Theme.of(context)no setter - width → double
-
Available on GetInterface, provided by the GetNavigationExt extension
The horizontal extent of this size.no setter - window → PlatformDispatcher
-
Available on GetInterface, provided by the GetNavigationExt extension
The window to which this binding is bound.no setter
Methods
-
addKey(
GlobalKey< NavigatorState> newKey) → GlobalKey<NavigatorState> ? -
Available on GetInterface, provided by the GetNavigationExt extension
-
appUpdate(
) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
args<
T> () → T -
Available on GetInterface, provided by the GetNavigationExt extension
-
back<
T> ({T? result, bool canPop = true, int times = 1, String? id}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.popUntil() shortcut.
-
backLegacy<
T> ({T? result, bool closeOverlays = false, bool canPop = true, int times = 1, String? id}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Pop the current page, snackbar, dialog or bottomsheet in the stack -
changeTheme(
ThemeData theme) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
changeThemeMode(
ThemeMode themeMode) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
close<
T extends Object> ({bool closeAll = true, bool closeSnackbar = true, bool closeDialog = true, bool closeBottomSheet = true, String? id, T? result}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.popUntil() (with predicate) shortcut .
-
closeAllBottomSheets(
{String? id}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
closeAllDialogs(
{String? id}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
closeAllDialogsAndBottomSheets(
String? id) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
closeAllOverlays(
) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
closeAllSnackbars(
) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
closeBottomSheet<
T> ({String? id, T? result}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
-
closeCurrentSnackbar(
) → Future< void> -
Available on GetInterface, provided by the GetNavigationExt extension
-
closeDialog<
T> ({String? id, T? result}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Close the currently open dialog, returning aresult, if provided -
closeOverlay<
T> ({String? id, T? result}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Close the current overlay returning theresult, if provided -
delegate<
TDelegate extends RouterDelegate< (TPage> , TPage>) → TDelegate? -
Available on GetInterface, provided by the GetNavigationExt extension
Casts the stored router delegate to a desired type -
forceAppUpdate(
) → Future< void> -
Available on GetInterface, provided by the GetNavigationExt extension
As a rule, Flutter knows which widget to update, so this command is rarely needed. We can mention situations where you use const so that widgets are not updated with setState, but you want it to be forcefully updated when an event like language change happens. using context to make the widget dirty for performRebuild() is a viable solution. However, in situations where this is not possible, or at least, is not desired by the developer, the only solution for updating widgets that Flutter does not want to update is to use reassemble to forcibly rebuild all widgets. Attention: calling this function will reconstruct the application from the sketch, use this with caution. Your entire application will be rebuilt, and touch events will not work until the end of rendering. 通常情况下,Flutter 能够智能的知道要更新哪个部件,因此很少需要这条命令。 它通过对 Widget 树的有效管理和 setState 方法的调用来实现这一点。 因此,在绝大多数情况下,开发者不需要手动介入 Widget 的更新过程。 如果在 Widget 构建过程中使用了 const 关键字,该 Widget 及其子树将不会在 setState 调用时更新。 这是因为 const 创建的是编译时常量,Flutter 认为它们在整个应用生命周期内不会改变。 在一些特殊场景下,尽管 Widget 被定义为 const,但仍然需要强制更新。 一个典型的例子是应用语言更改时。 虽然可以通过使 Widget 变"脏" (dirty) 来强制重建 (performRebuild),但在某些情况下,这可能不是可行的或者开发者不希望这样做。 在 Flutter 不愿意更新 Widget,而开发者又确实需要更新时,可以使用 reassemble 方法强制整个应用的 Widget 树进行重建。 这相当于从头开始重构应用的 UI。 ! 注意,调用 reassemble 会导致整个应用重新构建,这是一个非常重的操作。 ! 在渲染完成之前,触摸事件等可能无法正常工作。因此,除非确有必要,否则应避免使用此方法。 -
nestedKey(
String? key) → GetDelegate? -
Available on GetInterface, provided by the GetNavigationExt extension
-
off<
T> (Widget page(), {bool? opaque, Transition? transition, Curve? curve, bool? popGesture, String? id, String? routeName, dynamic arguments, List< BindingsInterface> bindings = const [], bool fullscreenDialog = false, bool preventDuplicates = true, Duration? duration, double gestureWidth(BuildContext context)?}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.pushReplacement() shortcut .
-
offAll<
T> (Widget page(), {bool predicate(GetPage)?, bool? opaque, bool? popGesture, String? id, String? routeName, dynamic arguments, List< BindingsInterface> bindings = const [], bool fullscreenDialog = false, Transition? transition, Curve? curve, Duration? duration, double gestureWidth(BuildContext context)?}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Push apageand pop several pages in the stack untilpredicatereturns true.predicateis optional -
offAllNamed<
T> (String newRouteName, {dynamic arguments, String? id, Map< String, String> ? parameters}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.pushNamedAndRemoveUntil() shortcut.
-
offAndToNamed<
T> (String page, {dynamic arguments, String? id, dynamic result, Map< String, String> ? parameters}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.popAndPushNamed() shortcut.
-
offNamed<
T> (String page, {dynamic arguments, String? id, Map< String, String> ? parameters}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.pushReplacementNamed() shortcut.
-
offNamedUntil<
T> (String page, bool predicate(GetPage)?, {String? id, dynamic arguments, Map< String, String> ? parameters}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.pushNamedAndRemoveUntil() shortcut.
-
offUntil<
T> (Widget page(), bool predicate(GetPage), [Object? arguments, String? id]) → Future< T?> -
Available on GetInterface, provided by the GetNavigationExt extension
-
removeRoute(
String name, {String? id}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.removeRoute() shortcut.
-
searchDelegate(
String? k) → GetDelegate -
Available on GetInterface, provided by the GetNavigationExt extension
根据 key 获取 GetDelegate -
to<
T extends Object?> (Widget page(), {bool? opaque, Transition? transition, Curve? curve, Duration? duration, String? id, String? routeName, bool fullscreenDialog = false, dynamic arguments, List< BindingsInterface> bindings = const [], bool preventDuplicates = true, bool? popGesture, bool showCupertinoParallax = true, double gestureWidth(BuildContext context)?, bool rebuildStack = true, PreventDuplicateHandlingMode preventDuplicateHandlingMode = PreventDuplicateHandlingMode.reorderRoutes}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.push() shortcut.
-
toNamed<
T> (String page, {dynamic arguments, dynamic id, bool preventDuplicates = true, Map< String, String> ? parameters}) → Future<T?> ? -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.pushNamed() shortcut.
-
until(
bool predicate(GetPage), {String? id}) → void -
Available on GetInterface, provided by the GetNavigationExt extension
Navigation.popUntil() shortcut.
-
updateLocale(
Locale l) → Future< void> -
Available on GetInterface, provided by the GetNavigationExt extension